"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _path = require("path");

function moduleFileType(...exts) {
  return imported => exts.some(ext => (0, _path.extname)(imported.moduleName) === ext);
}

function sortModuleFileExtension(comparator) {
  return (firstImport, secondImport) => {
    const first = firstImport.moduleName;
    const second = secondImport.moduleName;
    return comparator((0, _path.extname)(first), (0, _path.extname)(second));
  };
}

function isTypeImport(imported) {
  return imported.type === 'import-type';
}

function _default(styleApi) {
  const {
    and,
    isAbsoluteModule,
    isRelativeModule,
    moduleName,
    member,
    name,
    not,
    unicode // isTypeImport,
    // moduleFileType,
    // sortModuleFileExtension,

  } = styleApi;
  return [// import "foo"
  {
    match: and(not(isTypeImport), isAbsoluteModule, moduleFileType('', '.js')),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, // import "foo.css"
  {
    match: and(not(isTypeImport), isAbsoluteModule),
    sort: [sortModuleFileExtension(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, // import type "foo"
  {
    match: and(isTypeImport, isAbsoluteModule),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, // import "./foo"
  {
    match: and(not(isTypeImport), isRelativeModule, moduleFileType('', '.js')),
    sort: moduleName(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, // import "./foo.css"
  {
    match: and(not(isTypeImport), isRelativeModule),
    sort: [sortModuleFileExtension(unicode), moduleName(unicode)],
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }, // import type "./foo"
  {
    match: and(isTypeImport, isRelativeModule),
    sort: member(unicode),
    sortNamedMembers: name(unicode)
  }, {
    separator: true
  }];
}